@@ -78,6 +78,10 @@ class EnviarPedido(Plugavel):
         return conexao.post(segunda_tentativa)
 
     def enviar(self):
+        if not self.configuracao_pagamento:
+            return {"content": {"mensagem": u"A forma de pagamento selecionada não está configurada na loja.", "fatal": True}, "status": 404, "reenviar": False}
+        if not self.configuracao_pagamento.forma_de_pagamento["configurado"] or not self.configuracao_pagamento.ativo:
+            return {"content": {"mensagem": u"A forma de pagamento selecionada não está configurada na loja.", "fatal": True}, "status": 404, "reenviar": False}
         if self.requisicao.url:
             resultado = self.post()
         else:
