@@ -52,7 +52,13 @@ class Formatador(object):
 
     @classmethod
     def converte_tel_em_tupla_com_ddd(cls, telefone):
-        return telefone[:2], telefone[2:]
+        ddd = telefone[:2]
+        numero = telefone[2:]
+        if not ddd.isdigit() or not telefone.isdigit():
+            return '', ''
+        if int(ddd) < 11:
+            return '', ''
+        return ddd, numero
 
     @classmethod
     def trata_email_com_mais(cls, email):
